local revision = tonumber(("$Revision: 67911 $"):match("%d+"))
if not NSD_REVISION or revision > NSD_REVISION then
    NSD_REVISION = revision
    NSD_DATE = ("$Date: 2008-04-03 13:49:18 -0400 (Thu, 03 Apr 2008) $"):match("%d%d%d%d%-%d%d%-%d%d")
end

-- localisations
local L = Rock("LibRockLocale-1.0"):GetTranslationNamespace("ShakedownStandardUI")
L:AddTranslations("enUS", function() return {
    ["Current Zone"] = true,
    ["Current Sub Zone"] = true,
    ["Zone PVP Info"] = true,
    ["PVP Arena Info"] = true,
    ["Autofollow status"] = true,
    ["Raid Warning"] = true,
    ["UI Error"] = true,
    ["UI Message"] = true,
    ["Mirror Timer %d"] = true,
    ["Casting Bar"] = true,
    ["Quest Watch Frame"] = true,
    ["Durability"] = true,
    ["Standard WoW GUI"] = true,
} end)

-- constants
local TIMER_FREQ = 3
local TIMER_ID = "StandardUIShakedown"

-- create the class
local Addon = AddonBase:new("StandardUI", L["Standard WoW GUI"], true)
if not Addon then return end
Rock("LibRockHook-1.0"):Embed(Addon)
Rock("LibRockTimer-1.0"):Embed(Addon)

-- members
Addon.mirrorCoveringFrame = nil
Addon.castbarCoveringFrame = nil
Addon.questWatchCoveringFrame = nil
Addon.durabilityCoveringFrame = nil
Addon.oldPVPInfoTextString = ""
Addon.oldPVPArenaTextString = ""
Addon.showErrorMsg = false

function Addon:Start()
    -- set / store text values
    ZoneTextString:SetText(L["Current Zone"])
    SubZoneTextString:SetText(L["Current Sub Zone"])
    self.oldPVPInfoTextString = PVPInfoTextString:GetText()
    PVPInfoTextString:SetText(L["Zone PVP Info"])
    self.oldPVPArenaTextString = PVPArenaTextString:GetText()
    PVPArenaTextString:SetText(L["PVP Arena Info"])
    AutoFollowStatusText:SetText(L["Autofollow status"])
    
    -- show auto follow
    AutoFollowStatus:Show()
    
    -- set the frames to display for 5 mins
    FadingFrame_SetHoldTime(ZoneTextFrame, 300)
    FadingFrame_SetHoldTime(SubZoneTextFrame, 300)
    FadingFrame_SetHoldTime(AutoFollowStatus, 300)
    
    -- show the text frames
    FadingFrame_Show(ZoneTextFrame)
    FadingFrame_Show(SubZoneTextFrame)
    FadingFrame_Show(AutoFollowStatus)
    
    -- create a frame covering the mirror bars
    if not self.mirrorCoveringFrame then
        self.mirrorCoveringFrame = { nil, nil, nil }
        for i = 1, 3 do
            self.mirrorCoveringFrame[i] = CreateFrame("Frame", "mirrorCoveringFrame"..tostring(i), UIParent)
            self.mirrorCoveringFrame[i]:SetBackdrop({ bgFile = self.backdropNoDrag, })
            self.mirrorCoveringFrame[i]:SetPoint("TOPLEFT", getglobal("MirrorTimer"..tostring(i).."StatusBar"), "TOPLEFT", 0, 0)
            self.mirrorCoveringFrame[i]:SetPoint("BOTTOMRIGHT", getglobal("MirrorTimer"..tostring(i).."StatusBar"), "BOTTOMRIGHT", 0, 0)
            local label = self.mirrorCoveringFrame[i]:CreateFontString("mirrorCoveringFrame_label", "BORDER")
            label:SetPoint("TOPLEFT", self.mirrorCoveringFrame[i], "TOPLEFT", 0, 0)
            label:SetFont(NumberFontNormal:GetFont(), 12, "OUTLINE")
            label:SetText(L["Mirror Timer %d"]:format(i))
        end
    else
        for i = 1, 3 do
            self.mirrorCoveringFrame[i]:Show()
        end
    end
    
    -- create a frame covering the cast bar
    if not self.castbarCoveringFrame then
        self.castbarCoveringFrame = CreateFrame("Frame", "castbarCoveringFrame", UIParent)
        self.castbarCoveringFrame:SetBackdrop({ bgFile = self.backdropNoDrag, })
        self.castbarCoveringFrame:SetPoint("TOPLEFT", CastingBarFrame, "TOPLEFT", 0, 0)
        self.castbarCoveringFrame:SetPoint("BOTTOMRIGHT", CastingBarFrame, "BOTTOMRIGHT", 0, 0)
        local label = self.castbarCoveringFrame:CreateFontString("castbarCoveringFrame_label", "BORDER")
        label:SetPoint("TOPLEFT", self.castbarCoveringFrame, "TOPLEFT", 0, 0)
        label:SetFont(NumberFontNormal:GetFont(), 12, "OUTLINE")
        label:SetText(L["Casting Bar"])
    else
        self.castbarCoveringFrame:Show()
    end
    
    -- create a frame covering the quest watch
    if not self.questWatchCoveringFrame then
        self.questWatchCoveringFrame = CreateFrame("Frame", "questWatchCoveringFrame", UIParent)
        self.questWatchCoveringFrame:SetBackdrop({ bgFile = self.backdropNoDrag, })
        self.questWatchCoveringFrame:SetPoint("TOPRIGHT", QuestWatchFrame, "TOPRIGHT", 0, 0)
        self.questWatchCoveringFrame:SetWidth(QuestWatchFrame:GetWidth())
        self.questWatchCoveringFrame:SetHeight(200)
        local label = self.questWatchCoveringFrame:CreateFontString("questWatchCoveringFrame_label", "BORDER")
        label:SetPoint("TOPLEFT", self.questWatchCoveringFrame, "TOPLEFT", 0, 0)
        label:SetFont(NumberFontNormal:GetFont(), 12, "OUTLINE")
        label:SetText(L["Quest Watch Frame"])
    else
        self.questWatchCoveringFrame:Show()
    end
    
    -- create a frame covering the durability indicator
    if not self.durabilityCoveringFrame then
        self.durabilityCoveringFrame = CreateFrame("Frame", "durabilityCoveringFrame", UIParent)
        self.durabilityCoveringFrame:SetBackdrop({ bgFile = self.backdropNoDrag, })
        self.durabilityCoveringFrame:SetPoint("TOPLEFT", DurabilityFrame, "TOPLEFT", 0, 0)
        self.durabilityCoveringFrame:SetPoint("BOTTOMRIGHT", DurabilityFrame, "BOTTOMRIGHT", 0, 0)
        local label = self.durabilityCoveringFrame:CreateFontString("durabilityCoveringFrame_label", "BORDER")
        label:SetPoint("TOPLEFT", self.durabilityCoveringFrame, "TOPLEFT", 0, 0)
        label:SetFont(NumberFontNormal:GetFont(), 12, "OUTLINE")
        label:SetText(L["Durability"])
    else
        self.durabilityCoveringFrame:Show()
    end
    
    -- show the voice chat thingy and reshow it after mouse leaves
    VoiceChatTalkers:SetAlpha(1.0)
    self:AddSecureScriptHook(VoiceChatTalkers, "OnLeave", self.VoiceChatTalkers_OnLeave, self)
    
    -- show a message now
    self:ShowMessage()
    
    -- schedule repeating messages
    self:AddRepeatingTimer(TIMER_ID, TIMER_FREQ, self.ShowMessage, self)

end

function Addon:Stop()

    -- hide the covering frames
    for i = 1, 3 do
        self.mirrorCoveringFrame[i]:Hide()
    end
    self.castbarCoveringFrame:Hide()
    self.questWatchCoveringFrame:Hide()
    self.durabilityCoveringFrame:Hide()
    
    -- hide auto follow
    AutoFollowStatus:Hide()

    -- reset the old values
    FadingFrame_SetHoldTime(ZoneTextFrame, 0)
    FadingFrame_SetHoldTime(SubZoneTextFrame, 0)
    FadingFrame_SetHoldTime(AutoFollowStatus, 0)
    PVPInfoTextString:SetText(self.oldPVPInfoTextString)
    PVPArenaTextString:SetText(self.oldPVPArenaTextString)

    -- hide the voice chat thingy
    VoiceChatTalkers:SetAlpha(0)
    
    self:RemoveHook(VoiceChatTalkers, "OnLeave")
    
    self:RemoveTimer(TIMER_ID)
    
end

local white = {r=1, g=1, b=1}
-- show a message in the errors frame
function Addon:ShowMessage()

    -- UI errors/messages
    if self.showErrorMsg then
        UIErrorsFrame:AddMessage(L["UI Error"], 1.0, 0.1, 0.1, 1.0)
    else
        UIErrorsFrame:AddMessage(L["UI Message"], NORMAL_FONT_COLOR.r, NORMAL_FONT_COLOR.g, NORMAL_FONT_COLOR.b, 1.0)
    end
    self.showErrorMsg = not self.showErrorMsg
    
    -- raid warning
    RaidNotice_AddMessage(RaidWarningFrame, L["Raid Warning"], white)

end

-- called when the mouse leaves VoiceChatTalkers - re-show the frame
function Addon:VoiceChatTalkers_OnLeave()
    VoiceChatTalkers:SetAlpha(1.0)
end
